Quark Report

#### Analysis Result

The # of rules for each confidence

100% $effective_rules_number_100$
80% $effective_rules_number_80$
60% $effective_rules_number_60$
40% $effective_rules_number_40$
20% $effective_rules_number_20$
0% $effective_rules_number_0$

#### Sample Information

File name
  $filename$
MD5
  $md5$
File size
  $filesize$ Mb
Labels
  $five_labels_html$

### Select labels to see max confidence in radar chart

$all_labels_html$

### The labels with 100% confidence crimes

$five_labels_html$
Search crime
Confidence filter

Rule No. | Crime Description | Confidence
--- | --- | ---
$report_content$

$report_data$